@@ -30,6 +30,10 @@
  * appearing in the registered #GtkTextBuffer<!-- -->s.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcecompletionwords.h"
 #include "gtksourcecompletionwordslibrary.h"
 #include "gtksourcecompletionwordsbuffer.h"
@@ -427,24 +431,24 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_NAME,
 	                                 g_param_spec_string ("name",
-	                                                      C_("Object", "Name"),
-	                                                      _("The provider name"),
+	                                                      "Name",
+	                                                      "The provider name",
 	                                                      NULL,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
 	g_object_class_install_property (object_class,
 	                                 PROP_ICON,
 	                                 g_param_spec_object ("icon",
-	                                                      _("Icon"),
-	                                                      _("The provider icon"),
+	                                                      "Icon",
+	                                                      "The provider icon",
 	                                                      GDK_TYPE_PIXBUF,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
 	g_object_class_install_property (object_class,
 	                                 PROP_PROPOSALS_BATCH_SIZE,
 	                                 g_param_spec_uint ("proposals-batch-size",
-	                                                    _("Proposals Batch Size"),
-	                                                    _("Number of proposals added in one batch"),
+	                                                    "Proposals Batch Size",
+	                                                    "Number of proposals added in one batch",
 	                                                    1,
 	                                                    G_MAXUINT,
 	                                                    300,
@@ -453,8 +457,8 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_SCAN_BATCH_SIZE,
 	                                 g_param_spec_uint ("scan-batch-size",
-	                                                    _("Scan Batch Size"),
-	                                                    _("Number of lines scanned in one batch"),
+	                                                    "Scan Batch Size",
+	                                                    "Number of lines scanned in one batch",
 	                                                    1,
 	                                                    G_MAXUINT,
 	                                                    50,
@@ -463,8 +467,8 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_MINIMUM_WORD_SIZE,
 	                                 g_param_spec_uint ("minimum-word-size",
-	                                                    _("Minimum Word Size"),
-	                                                    _("The minimum word size to complete"),
+	                                                    "Minimum Word Size",
+	                                                    "The minimum word size to complete",
 	                                                    2,
 	                                                    G_MAXUINT,
 	                                                    2,
@@ -473,8 +477,8 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_INTERACTIVE_DELAY,
 	                                 g_param_spec_int ("interactive-delay",
-	                                                   _("Interactive Delay"),
-	                                                   _("The delay before initiating interactive completion"),
+	                                                   "Interactive Delay",
+	                                                   "The delay before initiating interactive completion",
 	                                                   -1,
 	                                                   G_MAXINT,
 	                                                   50,
@@ -483,8 +487,8 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_PRIORITY,
 	                                 g_param_spec_int ("priority",
-	                                                   _("Priority"),
-	                                                   _("Provider priority"),
+	                                                   "Priority",
+	                                                   "Provider priority",
 	                                                   G_MININT,
 	                                                   G_MAXINT,
 	                                                   0,
@@ -500,8 +504,8 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_ACTIVATION,
 					 g_param_spec_flags ("activation",
-							     _("Activation"),
-							     _("The type of activation"),
+							     "Activation",
+							     "The type of activation",
 							     GTK_SOURCE_TYPE_COMPLETION_ACTIVATION,
 							     GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE |
 							     GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED,
