@@ -20,14 +20,13 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef GTK_SOURCE_BUFFER_OUTPUT_STREAM_H
-#define GTK_SOURCE_BUFFER_OUTPUT_STREAM_H
+#ifndef __GTK_SOURCE_BUFFER_OUTPUT_STREAM_H__
+#define __GTK_SOURCE_BUFFER_OUTPUT_STREAM_H__
 
 #include <gtk/gtk.h>
 #include "gtksourcetypes.h"
 #include "gtksourcetypes-private.h"
 #include "gtksourcebuffer.h"
-#include "gtksourcefile.h"
 
 G_BEGIN_DECLS
 
@@ -75,4 +74,4 @@ guint			 gtk_source_buffer_output_stream_get_num_fallbacks
 
 G_END_DECLS
 
-#endif /* GTK_SOURCE_BUFFER_OUTPUT_STREAM_H */
+#endif /* __GTK_SOURCE_BUFFER_OUTPUT_STREAM_H__ */
