@@ -97,6 +97,10 @@
  * GtkSourceCompletionInfo for the main completion window.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcecompletion.h"
 #include "gtksourcecompletion-private.h"
 #include "gtksourcecompletionmodel.h"
