@@ -55,70 +55,72 @@ enum
 {
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_MARKUP,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_ICON,
+	GTK_SOURCE_COMPLETION_MODEL_COLUMN_ICON_NAME,
+	GTK_SOURCE_COMPLETION_MODEL_COLUMN_GICON,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_PROPOSAL,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_PROVIDER,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
 	GTK_SOURCE_COMPLETION_MODEL_N_COLUMNS
 };
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 GType    gtk_source_completion_model_get_type			(void) G_GNUC_CONST;
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 GtkSourceCompletionModel *
          gtk_source_completion_model_new			(void);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 void     gtk_source_completion_model_add_proposals              (GtkSourceCompletionModel    *model,
 								 GtkSourceCompletionProvider *provider,
 								 GList                       *proposals);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_is_empty			(GtkSourceCompletionModel    *model,
 								 gboolean                     only_visible);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 void     gtk_source_completion_model_set_visible_providers	(GtkSourceCompletionModel    *model,
 								 GList                       *providers);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 GList   *gtk_source_completion_model_get_visible_providers	(GtkSourceCompletionModel    *model);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 GList   *gtk_source_completion_model_get_providers		(GtkSourceCompletionModel    *model);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 void     gtk_source_completion_model_set_show_headers		(GtkSourceCompletionModel    *model,
 								 gboolean                     show_headers);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_iter_is_header		(GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_iter_previous		(GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_first_proposal             (GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_last_proposal              (GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_next_proposal              (GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_previous_proposal          (GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_has_info                   (GtkSourceCompletionModel    *model);
 
-G_GNUC_INTERNAL
+GTK_SOURCE_INTERNAL
 gboolean gtk_source_completion_model_iter_equal			(GtkSourceCompletionModel    *model,
 								 GtkTreeIter                 *iter1,
 								 GtkTreeIter                 *iter2);
