@@ -20,6 +20,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourceencoding.h"
 #include "gtksourceencoding-private.h"
 #include "gtksourceview-i18n.h"
@@ -491,21 +495,6 @@ gtk_source_encoding_get_name (const GtkSourceEncoding* enc)
 	return (enc->name == NULL) ? _("Unknown") : _(enc->name);
 }
 
-static gboolean
-data_exists (GSList         *list,
-	     const gpointer  data)
-{
-	for (; list != NULL; list = g_slist_next (list))
-	{
-		if (list->data == data)
-		{
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
-
 static GSList *
 strv_to_list (const gchar * const *enc_str)
 {
@@ -526,7 +515,7 @@ strv_to_list (const gchar * const *enc_str)
 		enc = gtk_source_encoding_get_from_charset (charset);
 
 		if (enc != NULL &&
-		    !data_exists (res, (gpointer)enc))
+		    g_slist_find (res, enc) == NULL)
 		{
 			res = g_slist_prepend (res, (gpointer)enc);
 		}
@@ -545,7 +534,7 @@ remove_duplicates_keep_first (GSList *list)
 	{
 		gpointer cur_encoding = l->data;
 
-		if (!data_exists (new_list, cur_encoding))
+		if (g_slist_find (new_list, cur_encoding) == NULL)
 		{
 			new_list = g_slist_prepend (new_list, cur_encoding);
 		}
@@ -569,7 +558,7 @@ remove_duplicates_keep_last (GSList *list)
 	{
 		gpointer cur_encoding = l->data;
 
-		if (!data_exists (new_list, cur_encoding))
+		if (g_slist_find (new_list, cur_encoding) == NULL)
 		{
 			new_list = g_slist_prepend (new_list, cur_encoding);
 		}
@@ -683,8 +672,8 @@ gtk_source_encoding_get_default_candidates (void)
 	g_variant_ref_sink (encodings_variant);
 
 	encodings_strv = g_variant_get_strv (encodings_variant, NULL);
-
 	encodings_list = strv_to_list (encodings_strv);
+	g_free (encodings_strv);
 
 	/* Ensure that UTF-8 and CURRENT are present. */
 	encodings_list = g_slist_prepend (encodings_list,
