@@ -2,7 +2,7 @@
 /* gtksourceiter.h
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2014, 2016 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef GTK_SOURCE_ITER_H
-#define GTK_SOURCE_ITER_H
+#ifndef __GTK_SOURCE_ITER_H__
+#define __GTK_SOURCE_ITER_H__
 
 #include <gtk/gtk.h>
 #include "gtksourcetypes-private.h"
@@ -48,22 +48,6 @@ void		_gtk_source_iter_extend_selection_word			(const GtkTextIter *location,
 									 GtkTextIter       *start,
 									 GtkTextIter       *end);
 
-GTK_SOURCE_INTERNAL
-gboolean	_gtk_source_iter_starts_extra_natural_word		(const GtkTextIter *iter,
-									 gboolean           visible);
-
-GTK_SOURCE_INTERNAL
-gboolean	_gtk_source_iter_ends_extra_natural_word		(const GtkTextIter *iter,
-									 gboolean           visible);
-
-GTK_SOURCE_INTERNAL
-void		_gtk_source_iter_get_leading_spaces_end_boundary	(const GtkTextIter *iter,
-									 GtkTextIter       *leading_end);
-
-GTK_SOURCE_INTERNAL
-void		_gtk_source_iter_get_trailing_spaces_start_boundary	(const GtkTextIter *iter,
-									 GtkTextIter       *trailing_start);
-
 /* Internal functions, in the header for unit tests. */
 
 GTK_SOURCE_INTERNAL
@@ -84,6 +68,12 @@ void		_gtk_source_iter_forward_extra_natural_word_end		(GtkTextIter *iter);
 GTK_SOURCE_INTERNAL
 void		_gtk_source_iter_backward_extra_natural_word_start	(GtkTextIter *iter);
 
+GTK_SOURCE_INTERNAL
+gboolean	_gtk_source_iter_starts_extra_natural_word		(const GtkTextIter *iter);
+
+GTK_SOURCE_INTERNAL
+gboolean	_gtk_source_iter_ends_extra_natural_word		(const GtkTextIter *iter);
+
 GTK_SOURCE_INTERNAL
 gboolean	_gtk_source_iter_starts_word				(const GtkTextIter *iter);
 
@@ -95,4 +85,4 @@ gboolean	_gtk_source_iter_inside_word				(const GtkTextIter *iter);
 
 G_END_DECLS
 
-#endif /* GTK_SOURCE_ITER_H */
+#endif /* __GTK_SOURCE_ITER_H__ */
