@@ -20,6 +20,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcemarkattributes.h"
 #include "gtksourcemark.h"
 #include "gtksourceview-i18n.h"
@@ -402,7 +406,7 @@ gtk_source_mark_attributes_init (GtkSourceMarkAttributes *self)
  * Returns: (transfer full): a new source mark attributes.
  */
 GtkSourceMarkAttributes *
-gtk_source_mark_attributes_new ()
+gtk_source_mark_attributes_new (void)
 {
 	return g_object_new (GTK_SOURCE_TYPE_MARK_ATTRIBUTES, NULL);
 }
