@@ -260,7 +260,7 @@ _gtk_source_marks_sequence_is_empty (GtkSourceMarksSequence *seq)
 {
 	g_return_val_if_fail (GTK_SOURCE_IS_MARKS_SEQUENCE (seq), TRUE);
 
-	return g_sequence_get_length (seq->priv->seq) == 0;
+	return g_sequence_is_empty (seq->priv->seq);
 }
 
 void
