@@ -1,28 +1,29 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtksourcestyleschemechooserwidget.h
- * This file is part of gtksourceview
+ *
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2014 - Christian Hergert
- *               2014 - Ignacio Casal Quinteiro
+ * Copyright (C) 2014 - Ignacio Casal Quinteiro
  *
- * gtksourceview is free software; you can redistribute it and/or
+ * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * gtksourceview is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with gtksourceview. If not, see <http://www.gnu.org/licenses/>.
+ * along with GtkSourceView. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GTK_SOURCE_STYLE_SCHEME_CHOOSER_WIDGET_H
 #define GTK_SOURCE_STYLE_SCHEME_CHOOSER_WIDGET_H
 
 #include <gtk/gtk.h>
+#include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
 
@@ -47,8 +48,10 @@ struct _GtkSourceStyleSchemeChooserWidgetClass
 	GtkBinClass parent;
 };
 
+GTK_SOURCE_AVAILABLE_IN_3_16
 GType        gtk_source_style_scheme_chooser_widget_get_type              (void);
 
+GTK_SOURCE_AVAILABLE_IN_3_16
 GtkWidget   *gtk_source_style_scheme_chooser_widget_new                   (void);
 
 G_END_DECLS
