@@ -54,6 +54,7 @@ struct _TestWidgetPrivate
 	GtkSourceFile *file;
 	GtkSourceMap *map;
 	GtkCheckButton *show_map_checkbutton;
+	GtkCheckButton *smart_backspace_checkbutton;
 	GtkCheckButton *indent_width_checkbutton;
 	GtkSpinButton *indent_width_spinbutton;
 	GtkLabel *cursor_position_info;
@@ -337,23 +338,6 @@ highlight_current_line_toggled_cb (TestWidget     *self,
 	gtk_source_view_set_highlight_current_line (self->priv->view, enabled);
 }
 
-static void
-draw_spaces_toggled_cb (TestWidget     *self,
-			GtkCheckButton *button)
-{
-	gboolean draw_spaces = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-
-	if (draw_spaces)
-	{
-		gtk_source_view_set_draw_spaces (self->priv->view,
-						 GTK_SOURCE_DRAW_SPACES_ALL);
-	}
-	else
-	{
-		gtk_source_view_set_draw_spaces (self->priv->view, 0);
-	}
-}
-
 static void
 wrap_lines_toggled_cb (TestWidget     *self,
 		       GtkCheckButton *button)
@@ -836,22 +820,22 @@ bracket_matched_cb (GtkSourceBuffer           *buffer,
 	GEnumClass *eclass;
 	GEnumValue *evalue;
 
-	g_return_if_fail (iter != NULL);
-
 	eclass = G_ENUM_CLASS (g_type_class_ref (GTK_SOURCE_TYPE_BRACKET_MATCH_TYPE));
 	evalue = g_enum_get_value (eclass, state);
 
 	g_print ("Bracket match state: '%s'\n", evalue->value_nick);
 
+	g_type_class_unref (eclass);
+
 	if (state == GTK_SOURCE_BRACKET_MATCH_FOUND)
 	{
+		g_return_if_fail (iter != NULL);
+
 		g_print ("Matched bracket: '%c' at row: %"G_GINT32_FORMAT", col: %"G_GINT32_FORMAT"\n",
 		         gtk_text_iter_get_char (iter),
 		         gtk_text_iter_get_line (iter) + 1,
 		         gtk_text_iter_get_line_offset (iter) + 1);
 	}
-
-	g_type_class_unref (eclass);
 }
 
 static gchar *
@@ -972,7 +956,6 @@ test_widget_class_init (TestWidgetClass *klass)
 	gtk_widget_class_bind_template_callback (widget_class, show_right_margin_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, right_margin_position_value_changed_cb);
 	gtk_widget_class_bind_template_callback (widget_class, highlight_current_line_toggled_cb);
-	gtk_widget_class_bind_template_callback (widget_class, draw_spaces_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, wrap_lines_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, auto_indent_toggled_cb);
 	gtk_widget_class_bind_template_callback (widget_class, indent_spaces_toggled_cb);
@@ -984,6 +967,7 @@ test_widget_class_init (TestWidgetClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, view);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, map);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, show_map_checkbutton);
+	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, smart_backspace_checkbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, indent_width_checkbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, indent_width_spinbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, cursor_position_info);
@@ -1047,6 +1031,12 @@ test_widget_init (TestWidget *self)
 	                        "visible",
 	                        G_BINDING_SYNC_CREATE);
 
+	g_object_bind_property (self->priv->smart_backspace_checkbutton,
+	                        "active",
+	                        self->priv->view,
+	                        "smart-backspace",
+	                        G_BINDING_SYNC_CREATE);
+
 	g_signal_connect (self->priv->background_pattern,
 	                  "changed",
 	                  G_CALLBACK (on_background_pattern_changed),
